@@ -169,22 +169,18 @@ class TheBlockchainAPIResource:
     def get_nfts_belonging_to_address(
         self,
         public_key: str,
-        network: SolanaNetwork = SolanaNetwork.DEVNET,
-        candy_machine_id: Optional[str] = None
+        network: SolanaNetwork = SolanaNetwork.DEVNET
     ) -> list:
         """
         More info: https://docs.theblockchainapi.com/#tag/Solana-Wallet/paths/~1v1~1solana~1wallet~1nfts/get
         :param public_key:
         :param network:
-        :param candy_machine_id:
         :return:
         """
         payload = {
             "public_key": public_key,
             "network": network.value
         }
-        if candy_machine_id is not None:
-            payload["candy_machine_id"] = candy_machine_id
 
         response = self._request(
             payload=payload,
@@ -193,7 +189,7 @@ class TheBlockchainAPIResource:
         )
         if 'error_message' in response:
             raise Exception(response['error_message'])
-        return response
+        return response['nfts_owned']
 
     def derive_associated_token_account_address(
         self,
